import { PlatformName, ChainName } from "@wormhole-foundation/sdk-base";
import { ChainContext } from "./chain";
import { RpcConnection } from "./rpc";
import { ChainsConfig, TokenId, TxHash } from "./types";
import { WormholeMessageId } from "./attestation";
import { SignedTx } from "./types";
import { TokenBridge, AutomaticTokenBridge } from "./protocols/tokenBridge";
import { CircleBridge, AutomaticCircleBridge } from "./protocols/cctp";
import { WormholeCore } from "./protocols/core";
import { NativeAddress } from "./address";
export type PlatformCtr<P extends PlatformName> = {
    _platform: P;
    new (conf: ChainsConfig): Platform<P>;
};
export interface Platform<P extends PlatformName> {
    readonly platform: P;
    readonly conf: ChainsConfig;
    getChain(chain: ChainName): ChainContext<P>;
    getDecimals(chain: ChainName, rpc: RpcConnection<P>, token: TokenId | "native"): Promise<bigint>;
    getBalance(chain: ChainName, rpc: RpcConnection<P>, walletAddr: string, token: TokenId | "native"): Promise<bigint | null>;
    getRpc(chain: ChainName): RpcConnection<P>;
    sendWait(chain: ChainName, rpc: RpcConnection<P>, stxns: SignedTx[]): Promise<TxHash[]>;
    parseTransaction(chain: ChainName, rpc: RpcConnection<P>, txid: TxHash): Promise<WormholeMessageId[]>;
    parseAddress(chain: ChainName, address: string): NativeAddress<P>;
    getWormholeCore(rpc: RpcConnection<P>): Promise<WormholeCore<P>>;
    getTokenBridge(rpc: RpcConnection<P>): Promise<TokenBridge<P>>;
    getAutomaticTokenBridge(rpc: RpcConnection<P>): Promise<AutomaticTokenBridge<P>>;
    getAutomaticCircleBridge(rpc: RpcConnection<P>): Promise<AutomaticCircleBridge<P>>;
    getCircleBridge(rpc: RpcConnection<P>): Promise<CircleBridge<P>>;
}
//# sourceMappingURL=platform.d.ts.map