export class ChainContext {
    platform;
    chain;
    // Cached Protocol clients
    tokenBridge;
    autoTokenBridge;
    circleBridge;
    autoCircleBridge;
    constructor(platform, chain) {
        this.platform = platform;
        this.chain = chain;
    }
    // Utils for platform specific queries
    getDecimals = (token) => {
        return this.platform.getDecimals(this.chain, this.getRpc(), token);
    };
    getBalance = (walletAddr, token) => {
        return this.platform.getBalance(this.chain, this.getRpc(), walletAddr, token);
    };
    // Get details about the transaction
    parseTransaction = (txid) => {
        return this.platform.parseTransaction(this.chain, this.getRpc(), txid);
    };
    // Send a transaction and wait for it to be confirmed
    sendWait = (stxns) => {
        return this.platform.sendWait(this.chain, this.getRpc(), stxns);
    };
    // Take a native address and convert it to a UniversalAddress
    parseAddress = (address) => {
        return this.platform.parseAddress(this.chain, address);
    };
    // protocols
    getTokenBridge = async () => {
        this.tokenBridge = this.tokenBridge
            ? this.tokenBridge
            : await this.platform.getTokenBridge(this.getRpc());
        return this.tokenBridge;
    };
    getAutomaticTokenBridge = async () => {
        this.autoTokenBridge = this.autoTokenBridge
            ? this.autoTokenBridge
            : await this.platform.getAutomaticTokenBridge(this.getRpc());
        return this.autoTokenBridge;
    };
    getCircleBridge = async () => {
        this.circleBridge = this.circleBridge
            ? this.circleBridge
            : await this.platform.getCircleBridge(this.getRpc());
        return this.circleBridge;
    };
    getAutomaticCircleBridge = async () => {
        this.autoCircleBridge = this.autoCircleBridge
            ? this.autoCircleBridge
            : await this.platform.getAutomaticCircleBridge(this.getRpc());
        return this.autoCircleBridge;
    };
}
//# sourceMappingURL=chain.js.map