import { PlatformName } from "@wormhole-foundation/sdk-base";
import { UniversalOrNative, NativeAddress, ChainAddress } from "../address";
import { TokenId } from "../types";
import { VAA } from "../vaa";
import { UnsignedTransaction } from "../unsignedTransaction";
import "../payloads/tokenBridge";
export declare const ErrNotWrapped: (token: string) => Error;
export interface TokenBridge<P extends PlatformName> {
    isWrappedAsset(nativeAddress: UniversalOrNative<P>): Promise<boolean>;
    getOriginalAsset(nativeAddress: UniversalOrNative<P>): Promise<TokenId>;
    getWrappedNative(): Promise<NativeAddress<P>>;
    hasWrappedAsset(foreignToken: TokenId): Promise<boolean>;
    getWrappedAsset(foreignToken: TokenId): Promise<NativeAddress<P>>;
    isTransferCompleted(vaa: VAA<"Transfer"> | VAA<"TransferWithPayload">): Promise<boolean>;
    createAttestation(token_to_attest: UniversalOrNative<P>, payer?: UniversalOrNative<P>): AsyncGenerator<UnsignedTransaction>;
    submitAttestation(vaa: VAA<"AttestMeta">, payer?: UniversalOrNative<P>): AsyncGenerator<UnsignedTransaction>;
    transfer(sender: UniversalOrNative<P>, recipient: ChainAddress, token: UniversalOrNative<P> | "native", amount: bigint, payload?: Uint8Array): AsyncGenerator<UnsignedTransaction>;
    redeem(sender: UniversalOrNative<P>, vaa: VAA<"Transfer"> | VAA<"TransferWithPayload">, unwrapNative?: boolean): AsyncGenerator<UnsignedTransaction>;
}
export interface AutomaticTokenBridge<P extends PlatformName> {
    transfer(sender: UniversalOrNative<P>, recipient: ChainAddress, token: UniversalOrNative<P> | "native", amount: bigint, relayerFee: bigint, nativeGas?: bigint): AsyncGenerator<UnsignedTransaction>;
    redeem(sender: UniversalOrNative<P>, vaa: VAA<"TransferWithPayload">): AsyncGenerator<UnsignedTransaction>;
    getRelayerFee(sender: ChainAddress, recipient: ChainAddress, token: TokenId | "native"): Promise<bigint>;
}
//# sourceMappingURL=tokenBridge.d.ts.map