import { Layout, LayoutItem, LayoutToType, DynamicItemsOfLayout, CustomConversion, LayoutItemToType } from "@wormhole-foundation/sdk-base";
declare const uint8ArrayConversion: {
    readonly to: (val: Uint8Array) => Uint8Array;
    readonly from: (val: Uint8Array) => Uint8Array;
};
declare global {
    namespace Wormhole {
        interface PayloadLiteralToDescriptionMapping {
            Uint8Array: typeof uint8ArrayConversion;
        }
    }
}
type PayloadLiteral = keyof Wormhole.PayloadLiteralToDescriptionMapping;
type DescriptionOf<PL extends PayloadLiteral> = PL extends infer V extends PayloadLiteral ? Wormhole.PayloadLiteralToDescriptionMapping[V] : never;
type DescriptionToPayloadItem<D extends DescriptionOf<PayloadLiteral>> = [
    D
] extends [CustomConversion<Uint8Array, any>] ? {
    name: "payload";
    binary: "bytes";
    custom: D;
} : [D] extends [Layout] ? {
    name: "payload";
    binary: "object";
    layout: D;
} : never;
export type PayloadLiteralToPayloadType<PL extends PayloadLiteral> = DescriptionToPayloadItem<DescriptionOf<PL>> extends infer Item extends LayoutItem ? LayoutItemToType<Item> : never;
declare const baseLayout: readonly [{
    readonly name: "version";
    readonly binary: "uint";
    readonly size: 1;
    readonly custom: 1;
    readonly omit: true;
}, {
    readonly binary: "uint";
    readonly size: 4;
    readonly name: "guardianSet";
}, {
    readonly name: "signatures";
    readonly binary: "array";
    readonly lengthSize: 1;
    readonly layout: readonly [{
        readonly name: "guardianIndex";
        readonly binary: "uint";
        readonly size: 1;
    }, {
        readonly binary: "bytes";
        readonly size: 65;
        readonly custom: {
            readonly to: (val: Uint8Array) => import("./signature").Signature;
            readonly from: (val: import("./signature").Signature) => Uint8Array;
        };
        readonly name: "signature";
    }];
}, {
    readonly name: "timestamp";
    readonly binary: "uint";
    readonly size: 4;
}, {
    readonly name: "nonce";
    readonly binary: "uint";
    readonly size: 4;
}, {
    readonly custom: {
        to: (val: number) => "Solana" | "Btc" | "Algorand" | "Sui" | "Aptos" | "Osmosis" | "Wormchain" | "Near" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Base" | "Sei" | "Sepolia";
        from: (val: "Solana" | "Btc" | "Algorand" | "Sui" | "Aptos" | "Osmosis" | "Wormchain" | "Near" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Base" | "Sei" | "Sepolia") => number;
    };
    readonly binary: "uint";
    readonly size: 2;
    readonly name: "emitterChain";
}, {
    readonly binary: "bytes";
    readonly size: 32;
    readonly custom: {
        to: (val: Uint8Array) => import("./universalAddress").UniversalAddress;
        from: (val: import("./universalAddress").UniversalAddress) => Uint8Array;
    };
    readonly name: "emitterAddress";
}, {
    readonly binary: "uint";
    readonly size: 8;
    readonly name: "sequence";
}, {
    readonly name: "consistencyLevel";
    readonly binary: "uint";
    readonly size: 1;
}];
type BaseLayout = LayoutToType<typeof baseLayout>;
export interface VAA<PL extends PayloadLiteral = "Uint8Array"> extends BaseLayout {
    readonly payloadLiteral: PL;
    readonly payload: PayloadLiteralToPayloadType<PL>;
    readonly hash: Uint8Array;
}
export declare const create: <PL extends keyof Wormhole.PayloadLiteralToDescriptionMapping = "Uint8Array">(payloadLiteral: PL, vaaData: LayoutToType<readonly [{
    readonly binary: "uint";
    readonly size: 4;
    readonly name: "guardianSet";
}, {
    readonly name: "signatures";
    readonly binary: "array";
    readonly lengthSize: 1;
    readonly layout: readonly [{
        readonly name: "guardianIndex";
        readonly binary: "uint";
        readonly size: 1;
    }, {
        readonly binary: "bytes";
        readonly size: 65;
        readonly custom: {
            readonly to: (val: Uint8Array) => import("./signature").Signature;
            readonly from: (val: import("./signature").Signature) => Uint8Array;
        };
        readonly name: "signature";
    }];
}, {
    readonly name: "timestamp";
    readonly binary: "uint";
    readonly size: 4;
}, {
    readonly name: "nonce";
    readonly binary: "uint";
    readonly size: 4;
}, {
    readonly custom: {
        to: (val: number) => "Solana" | "Btc" | "Algorand" | "Sui" | "Aptos" | "Osmosis" | "Wormchain" | "Near" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Base" | "Sei" | "Sepolia";
        from: (val: "Solana" | "Btc" | "Algorand" | "Sui" | "Aptos" | "Osmosis" | "Wormchain" | "Near" | "Ethereum" | "Terra" | "Bsc" | "Polygon" | "Avalanche" | "Oasis" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Arbitrum" | "Optimism" | "Gnosis" | "Pythnet" | "Xpla" | "Base" | "Sei" | "Sepolia") => number;
    };
    readonly binary: "uint";
    readonly size: 2;
    readonly name: "emitterChain";
}, {
    readonly binary: "bytes";
    readonly size: 32;
    readonly custom: {
        to: (val: Uint8Array) => import("./universalAddress").UniversalAddress;
        from: (val: import("./universalAddress").UniversalAddress) => Uint8Array;
    };
    readonly name: "emitterAddress";
}, {
    readonly binary: "uint";
    readonly size: 8;
    readonly name: "sequence";
}, {
    readonly name: "consistencyLevel";
    readonly binary: "uint";
    readonly size: 1;
}, ...[DescriptionToPayloadItem<DescriptionOf<PL>> extends infer T ? T extends DescriptionToPayloadItem<DescriptionOf<PL>> ? T extends {
    custom: import("@wormhole-foundation/sdk-base/dist/esm/utils/layout/layout").PrimitiveType | import("@wormhole-foundation/sdk-base").FixedConversion<import("@wormhole-foundation/sdk-base/dist/esm/utils/layout/layout").PrimitiveType, any>;
} ? never : T extends import("@wormhole-foundation/sdk-base").ArrayLayoutItem | import("@wormhole-foundation/sdk-base").ObjectLayoutItem ? DynamicItemsOfLayout<T["layout"]> extends readonly LayoutItem[] ? [DynamicItemsOfLayout<T["layout"]>[number]] extends [never] ? never : { readonly [K in keyof T]: K extends "layout" ? DynamicItemsOfLayout<T["layout"]> : T[K]; } : never : T : never : never] extends [never] ? readonly [] : readonly [DescriptionToPayloadItem<DescriptionOf<PL>> extends infer T_1 ? T_1 extends DescriptionToPayloadItem<DescriptionOf<PL>> ? T_1 extends {
    custom: import("@wormhole-foundation/sdk-base/dist/esm/utils/layout/layout").PrimitiveType | import("@wormhole-foundation/sdk-base").FixedConversion<import("@wormhole-foundation/sdk-base/dist/esm/utils/layout/layout").PrimitiveType, any>;
} ? never : T_1 extends import("@wormhole-foundation/sdk-base").ArrayLayoutItem | import("@wormhole-foundation/sdk-base").ObjectLayoutItem ? DynamicItemsOfLayout<T_1["layout"]> extends readonly LayoutItem[] ? [DynamicItemsOfLayout<T_1["layout"]>[number]] extends [never] ? never : { readonly [K_1 in keyof T_1]: K_1 extends "layout" ? DynamicItemsOfLayout<T_1["layout"]> : T_1[K_1]; } : never : T_1 : never : never]]>) => VAA<PL>;
export declare function registerPayloadType<PL extends PayloadLiteral>(payloadLiteral: PL, payloadSerDe: CustomConversion<Uint8Array, any> | Layout): void;
export declare const serialize: <PL extends keyof Wormhole.PayloadLiteralToDescriptionMapping>(vaa: VAA<PL>) => Uint8Array;
export declare function deserialize<PL extends PayloadLiteral>(payloadLiteral: PL, data: Uint8Array | string): VAA<PL>;
export declare const serializePayload: <PL extends keyof Wormhole.PayloadLiteralToDescriptionMapping>(payloadLiteral: PL, payload: PayloadLiteralToPayloadType<PL>) => Uint8Array;
export declare const deserializePayload: <PL extends keyof Wormhole.PayloadLiteralToDescriptionMapping>(payloadLiteral: PL, data: Uint8Array | string) => PayloadLiteralToPayloadType<PL>;
export {};
//# sourceMappingURL=vaa.d.ts.map